summaryrefslogtreecommitdiffstats
path: root/kmix/viewswitches.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmix/viewswitches.cpp')
-rw-r--r--kmix/viewswitches.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmix/viewswitches.cpp b/kmix/viewswitches.cpp
index 3d3166bb..607b3397 100644
--- a/kmix/viewswitches.cpp
+++ b/kmix/viewswitches.cpp
@@ -21,7 +21,7 @@
#include "viewswitches.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqwidget.h>
#include <kdebug.h>
@@ -46,7 +46,7 @@ ViewSwitches::ViewSwitches(TQWidget* parent, const char* name, const TQString &
// Place enums right from the switches: This is done, so that there will be no
// ugly space on the left side, when no Switch is shown.
// Actually it is not really clear yet, why there is empty space at all: There are 0 items in
// the _layoutEnum, so it might be a tqsizeHint() or some other subtle tqlayout issue.
_layoutEnum = new TQVBoxLayout(_layoutMDW);
}
init();
@@ -118,9 +118,9 @@ TQWidget* ViewSwitches::add(MixDevice *md)
return mdw;
}
-TQSize ViewSwitches::tqsizeHint() const {
- //kdDebug(67100) << "ViewSwitches::tqsizeHint(): NewSize is " << _layoutMDW->tqsizeHint() << "\n";
- return( _layoutMDW->tqsizeHint() );
+TQSize ViewSwitches::sizeHint() const {
+ //kdDebug(67100) << "ViewSwitches::sizeHint(): NewSize is " << _layoutMDW->sizeHint() << "\n";
+ return( _layoutMDW->sizeHint() );
}
void ViewSwitches::constructionFinished() {
@@ -46,7 +46,7 @@ ViewSwitches::ViewSwitches(TQWidget* parent, const char* name, const TQString &
// ugly space on the left side, when no Switch is shown.
// Actually it is not really clear yet, why there is empty space at all: There are 0 items in
- // the _layoutEnum, so it might be a tqsizeHint() or some other subtle tqlayout issue.
+ // the _layoutEnum, so it might be a sizeHint() or some other subtle layout issue.
_layoutEnum = new TQVBoxLayout(_layoutMDW);
}